@@ -86,33 +86,8 @@ var LibraryPThread = {
     pthreads: {},
 #if ASSERTIONS
     nextWorkerID: 1,
-    debugInit() {
-      function pthreadLogPrefix() {
-        var t = 0;
-        if (runtimeInitialized && typeof _pthread_self != 'undefined'
-#if EXIT_RUNTIME
-        && !runtimeExited
-#endif
-        ) {
-          t = _pthread_self();
-        }
-        return `w:${workerID},t:${ptrToString(t)}: `;
-      }
-
-      // Prefix all err()/dbg() messages with the calling thread ID.
-      var origDbg = dbg;
-      dbg = (...args) => origDbg(pthreadLogPrefix() + args.join(' '));
-#if PTHREADS_DEBUG
-      // With PTHREADS_DEBUG also prefix all err() messages.
-      var origErr = err;
-      err = (...args) => origErr(pthreadLogPrefix() + args.join(' '));
-#endif
-    },
 #endif
     init() {
-#if ASSERTIONS
-      PThread.debugInit();
-#endif
       if ({{{ ENVIRONMENT_IS_MAIN_THREAD() }}}) {
         PThread.initMainThread();
       }
