@@ -4,6 +4,29 @@
  * SPDX-License-Identifier: MIT
  */
 
+#if ASSERTIONS || RUNTIME_DEBUG || AUTODEBUG
+var runtimeDebug = true; // Switch to false at runtime to disable logging at the right times
+
+// Used by XXXXX_DEBUG settings to output debug messages.
+function dbg(...args) {
+  if (!runtimeDebug && typeof runtimeDebug != 'undefined') return;
+#if ENVIRONMENT_MAY_BE_NODE && (PTHREADS || WASM_WORKERS)
+  // Avoid using the console for debugging in multi-threaded node applications
+  // See https://github.com/emscripten-core/emscripten/issues/14804
+  if (ENVIRONMENT_IS_NODE) {
+    // TODO(sbc): Unify with err/out implementation in shell.sh.
+    var fs = require('fs');
+    var utils = require('util');
+    var stringify = (a) => typeof a == 'object' ? utils.inspect(a) : a;
+    fs.writeSync(1, args.map(stringify).join(' ') + '\n');
+  } else
+#endif
+  // TODO(sbc): Make this configurable somehow.  Its not always convenient for
+  // logging to show up as warnings.
+  console.warn(...args);
+}
+#endif
+
 #if ASSERTIONS
 
 // Endianness check
@@ -129,6 +152,45 @@ function unexportedRuntimeSymbol(sym) {
   }
 }
 
+#if WASM_WORKERS || PTHREADS
+/**
+ * Override `err`/`out`/`dbg` to report thread / worker information
+ */
+function initWorkerLogging() {
+  function getLogPrefix() {
+#if WASM_WORKERS
+    if (Module['$ww']) {
+      return `ww:${Module['$ww']}:`
+    }
+#endif
+#if PTHREADS
+    var t = 0;
+    if (runtimeInitialized && typeof _pthread_self != 'undefined'
+#if EXIT_RUNTIME
+    && !runtimeExited
+#endif
+    ) {
+      t = _pthread_self();
+    }
+    return `w:${workerID},t:${ptrToString(t)}:`;
+#else
+    return `ww:0:`;
+#endif
+  }
+
+  // Prefix all dbg() messages with the calling thread info.
+  var origDbg = dbg;
+  dbg = (...args) => origDbg(getLogPrefix(), ...args);
+#if RUNTIME_DEBUG
+  // With RUNTIME_DEBUG also prefix all err() messages.
+  var origErr = err;
+  err = (...args) => origErr(getLogPrefix(), ...args);
+#endif
+}
+
+initWorkerLogging();
+#endif
+
 #if ASSERTIONS == 2
 
 var MAX_UINT8  = (2 **  8) - 1;
@@ -186,26 +248,3 @@ function prettyPrint(arg) {
   return arg;
 }
 #endif
-
-#if ASSERTIONS || RUNTIME_DEBUG || AUTODEBUG
-var runtimeDebug = true; // Switch to false at runtime to disable logging at the right times
-
-// Used by XXXXX_DEBUG settings to output debug messages.
-function dbg(...args) {
-  if (!runtimeDebug && typeof runtimeDebug != 'undefined') return;
-#if ENVIRONMENT_MAY_BE_NODE && PTHREADS
-  // Avoid using the console for debugging in multi-threaded node applications
-  // See https://github.com/emscripten-core/emscripten/issues/14804
-  if (ENVIRONMENT_IS_NODE) {
-    // TODO(sbc): Unify with err/out implementation in shell.sh.
-    var fs = require('fs');
-    var utils = require('util');
-    var stringify = (a) => typeof a == 'object' ? utils.inspect(a) : a;
-    fs.writeSync(1, args.map(stringify).join(' ') + '\n');
-  } else
-#endif
-  // TODO(sbc): Make this configurable somehow.  Its not always convenient for
-  // logging to show up as warnings.
-  console.warn(...args);
-}
-#endif
